@@ -1,4 +1,4 @@
-//  $Id: RtConfig.cc 1.8.1.1.1.24.2.1 Thu, 14 Oct 1999 11:49:55 -0700 cengiz $
+//  $Id: RtConfig.cc 1.8.1.1.1.27 Fri, 29 Oct 1999 15:37:07 -0700 cengiz $
 //
 //  Copyright (c) 1994 by the University of Southern California
 //  All rights reserved.
@@ -53,6 +53,7 @@ extern "C" {
 #include "util/version.hh"
 #include "re2dfa/regexp_nf.hh"
 #include "f_cisco.hh"
+#include "f_bcc.hh"
 #include "f_gated.hh"
 #include "f_rsd.hh"
 #include "rpsl/schema.hh"
@@ -87,11 +88,13 @@ typedef struct {
 CiscoConfig ciscoConfig;
 GatedConfig gatedConfig;
 RSdConfig   rsdConfig;
+BccConfig bccConfig;
 
 config_format_type config_formats[] = {
    { "rsd",         &rsdConfig },
    { "gated",       &gatedConfig },
    { "cisco",       &ciscoConfig },
+   { "bcc",       &bccConfig },
    //   { "rsd",         rsd_process_line },
    { "", 0 }
 };
@@ -137,21 +140,21 @@ void init_and_set_options (int argc, char **argv, char **envp) {
    ArgvInfo argTable[] = {
      // RAToolSet common arguments
      // key, type, src, dst, help
-     {"-T", ARGV_FUNC, (char *) &start_tracing,      (char *) NULL, 
+     {"-T", ARGV_FUNC, (char *) &start_tracing,         (char *) NULL, 
       "Start tracing the next argument"},
-     {"-D", ARGV_FUNC, (char *) &start_debugging,    (char *) NULL, 
+     {"-D", ARGV_FUNC, (char *) &start_debugging,       (char *) NULL, 
       "Start debugging the next argument"},
-     {"-version", ARGV_FUNC, (char *) &version,      (char *) NULL,
+     {"-version", ARGV_FUNC, (char *) &version,         (char *) NULL,
       "Show version"},
-     {"-rusage", ARGV_BOOL, (char *) NULL,           (char *) &opt_rusage,
+     {"-rusage", ARGV_BOOL, (char *) NULL,              (char *) &opt_rusage,
       "On termination print resource usage"},
-     {"-prompt", ARGV_STRING,  (char *) NULL,        (char *) &opt_prompt,
+     {"-prompt", ARGV_STRING,  (char *) NULL,           (char *) &opt_prompt,
       "Prompt"},
      
      IRR_COMMAND_LINE_OPTIONS,
 
      {"-config", ARGV_FUNC, (char *) &select_config_format, (char *) NULL, 
-      "Configuration format (cisco, gated or rsd)"},
+      "Configuration format (bcc, cisco, gated or rsd)"},
      {"-no_match_ip_inbound", ARGV_BOOL, 
       (char *) NULL, (char *) &CiscoConfig::forcedInboundMatchIP,
       "Produce a match ip clause for inbound maps.\n\t\t\t\tCisco only."},
@@ -203,7 +206,7 @@ main(int argc, char **argv, char **envp) {
    regexp_nf::expandASSets();
 
    RtConfig::loadDictionary();
-
+     
    commandparse();
    
    if (opt_prompt)
@@ -248,8 +251,8 @@ void RtConfig::configureRouter(char *name) {
    for (const AttrPeer *peer = itr.first(); peer; peer = itr.next()) {
       if (peer->protocol == bgp) {
 	 ASt peerAS = ((ItemASNO *) peer->searchOption("asno")->args->head())->asno;
-	 import(myAS, &myIP, peerAS, peer->peer);
-	 export(myAS, &myIP, peerAS, peer->peer);
+	 importP(myAS, &myIP, peerAS, peer->peer);
+	 exportP(myAS, &myIP, peerAS, peer->peer);
       }
    }
 }
@@ -484,3 +487,6 @@ void RtConfig::aspathAccessList(char *filter) {
    
    delete o;
 }
+
+
+
