@@ -1,4 +1,4 @@
-//  $Id: f_rsd.cc 1.4.2.12 Thu, 08 Apr 1999 15:23:32 -0700 cengiz $
+//  $Id: f_rsd.cc 1.4.2.13 Wed, 27 Oct 1999 18:49:39 -0700 cengiz $
 //
 //  Copyright (c) 1994 by the University of Southern California
 //  All rights reserved.
@@ -164,12 +164,12 @@ Filter *RSdConfig::fixBOLinRE(Filter *n, int asno) {
    return n;
 }
 
-void RSdConfig::export(ASt asno, IPAddr *addr, 
+void RSdConfig::exportP(ASt asno, IPAddr *addr, 
 		       ASt peerAS, IPAddr *peer_addr) {
    cerr << "Error: Unknown RtConfig/RSd command." << endl;
 }
 
-void RSdConfig::import(ASt asno, IPAddr *addr, 
+void RSdConfig::importP(ASt asno, IPAddr *addr, 
 		       ASt peerAS, IPAddr *peer_addr) {
    // get the aut-num objects
    const AutNum *autnum = irr->getAutNum(asno);
