@@ -1,4 +1,4 @@
-//  $Id: rawhoisc.cc 1.11.1.15.1.1 Thu, 14 Oct 1999 11:49:55 -0700 cengiz $
+//  $Id: rawhoisc.cc 1.11.1.15.1.3 Wed, 27 Oct 1999 18:49:39 -0700 cengiz $
 //
 //  Copyright (c) 1994 by the University of Southern California
 //  All rights reserved.
@@ -68,6 +68,7 @@ extern u_short htons(unsigned short);
 #include "rawhoisc.hh"
 #include "route.hh"
 #include "util/trace.hh"
+#include "rpsl/object_log.hh"
 
 void RAWhoisClient::Open(const char *_host, const int _port, const char *_sources) {
    if (_is_open)
@@ -458,12 +459,12 @@ ASt RAWhoisClient::getOrigin(char *format, ...)
   if (len = QueryResponse(result, "!r%s,l", buffer)) {
      Buffer b(result, len);
      List<Object> log;
-     extern void objectLog(Buffer &buf, List<Object> *log);
-     objectLog(b, &log);
+     extern void objectLog(const Buffer &buf, List<Object> &log);
+     objectLog(b, log);
 
-     for (ListIterator<Object> route(log); route; route++) {
+     for (ListIterator<Object> route(log); route; ++route) {
 	AttrGenericIterator<ItemPRFXV4> prefix(route, "route");
-	if (prefix()->prfxv4->get_length() >= 6) {
+	if (prefix->prfxv4->get_length() >= 6) {
 	   AttrGenericIterator<ItemASNO> objItr(route, "origin");
 	   const ItemASNO *asn = objItr.first();
 	   if (asn)
